#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Inspire by Conbagui's  tutorial 

# author: Pocholo
# date: 2/25/21

# Comments directed to http://gimpchat.com

# Installation:
# This script should be placed in the user plugins folder

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.

#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.#


from gimpfu import *
import gettext
import os, sys,time 

gettext.install("gimp20", gimp.locale_directory, unicode=True)

def create_paper_heart_valentie_cardV2(img, layer, filename1, filename2, customtext, fontname, size, imagesize):

	#Initiates the temporary state
    pdb.gimp_context_set_defaults()
    pdb.gimp_context_set_default_colors()
     
    #Make a duplicate from the background       
    backlayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Layer", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, backlayer, 0)
    pdb.gimp_layer_add_alpha(backlayer)   
    backlayer = pdb.gimp_image_merge_down(img, backlayer, CLIP_TO_IMAGE)
    pdb.gimp_image_set_active_layer(img, backlayer)
    pdb.gimp_item_set_name(backlayer, "Background")    
     
    #Import paths
    pdb.gimp_path_import(img, filename1, FALSE, TRUE)
    pdb.gimp_path_import(img, filename2, FALSE, TRUE)
        
    #Stroke fist path
    heartlayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Heart", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, heartlayer, 0)
    pdb.gimp_layer_add_alpha(heartlayer)
    pdb.gimp_drawable_fill(heartlayer, FILL_TRANSPARENT)
    pdb.gimp_context_set_foreground((255, 255, 255))
    pdb.gimp_context_set_line_width(150)
    pdb.gimp_context_set_line_cap_style(1)
    pdb.gimp_context_set_line_join_style(JOIN_ROUND)
    pdb.gimp_context_set_line_width_unit(PIXELS)
    pdb.gimp_context_set_stroke_method (STROKE_LINE)    
    pdb.gimp_context_set_dynamics("Dynamics Off")  
    pdb.gimp_context_set_paint_method("gimp-paintbrush")
    heart = pdb.gimp_image_get_vectors_by_name(img, "Heart")
    pdb.gimp_drawable_edit_stroke_item(heartlayer, heart)
    
    #Fill the rest of the heart
    pdb.gimp_image_select_item(img, 2, heart)
    pdb.gimp_edit_bucket_fill(heartlayer, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)	
    pdb.gimp_selection_none(img)
    
    #Stroke second path
    lineheart = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Heart Line", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, lineheart, 0)
    pdb.gimp_layer_add_alpha(lineheart)
    pdb.gimp_drawable_fill(lineheart, FILL_TRANSPARENT)
    pdb.gimp_context_set_foreground((255, 0, 0))
    pdb.gimp_context_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(15)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.1)
    pdb.gimp_context_set_dynamics("Fade")
    pdb.gimp_context_set_stroke_method(STROKE_PAINT_METHOD)
    heartline = pdb.gimp_image_get_vectors_by_name(img, "Line heart")    
    pdb.gimp_edit_stroke_vectors(lineheart, heartline)
    
    #Drop Shadow
    pdb.python_layerfx_drop_shadow(img, heartlayer,
										 ("Black"),   #color
											    35,   #opacity
												 0,   #contou - linear
												 0,   #noise
												 3,   #mode - multiply
												 7,   #spread
												30,   #size
											  -150,   #offset_angle
											    30,   #offset_distance
											  TRUE,   #knockout
											 FALSE)   #merge
    
    #Apply gaussian blur to heart 
    dshadow = pdb.gimp_image_get_layer_by_name(img, "Heart-dropshadow")
    pdb.plug_in_gauss(img, dshadow, 25, 25, 1)
       
    #Paint the flower
    flowerlayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Flower", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, flowerlayer, 0)
    pdb.gimp_layer_add_alpha(flowerlayer)
    pdb.gimp_drawable_fill(flowerlayer, FILL_TRANSPARENT)
    pdb.gimp_context_set_foreground((255, 0, 0))
    pdb.gimp_context_set_brush("Rose brush wb")
    pdb.gimp_context_set_brush_size(800)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.1)
    pdb.gimp_context_set_dynamics("Dynamics Off")  
    pdb.gimp_paintbrush_default(flowerlayer, 2, [970, 1085])
    pdb.gimp_drawable_colorize_hsl(flowerlayer, 0, 90, 50)
       
   #Drop Shadow
    pdb.python_layerfx_drop_shadow(img, flowerlayer,
										  ("Black"),   #color
											     35,   #opacity
												  0,   #contou - linear
												  0,   #noise
												  3,   #mode - multiply
												  7,   #spread
												 30,   #size
											   -150,   #offset_angle
											     30,   #offset_distance
											   TRUE,   #knockout
											  FALSE)   #merge
    
    
    #Create the text		
    textW = size/0.4
    textH = size/1.7
    
    pdb.gimp_context_set_foreground((255, 0, 0))
    #textLayer = pdb.gimp_text_fontname(img, None, 0, 0, customtext, 10, 1, size, PIXELS, fontname)
    textLayer = pdb.gimp_text_layer_new(img, customtext, fontname, size, PIXELS)
    pdb.gimp_image_add_layer(img, textLayer, 0)
    pdb.gimp_layer_add_alpha(textLayer)
    pdb.gimp_text_layer_set_justification(textLayer, 2)
    	
	#Resize text
    pdb.gimp_layer_scale (textLayer, textW, textH, TRUE)
			
	#Making the text centered	
    textLayer = pdb.gimp_image_get_active_layer(img)
    pdb.gimp_image_set_active_layer(img, textLayer)
    wh = pdb.gimp_drawable_width(textLayer)
    hh = pdb.gimp_drawable_height(textLayer)
    w = pdb.gimp_image_width(img)
    h = pdb.gimp_image_height(img)
    pdb.gimp_image_set_active_layer(img,textLayer)
    centerx=w/9
    centery=h/1.0
    adw=wh/9
    adh=hh/0.8
    sw=centerx - adw
    sh=centery - adh		
    pdb.gimp_layer_set_offsets(textLayer, sw, sh)
    pdb.gimp_layer_resize_to_image_size(textLayer)
      
    #Rename the text layer
    pdb.gimp_item_set_name(textLayer, "Text")
   
    #Stroke the text
    pdb.python_layer_fx_stroke(img, textLayer, 
                              (255, 255, 255),    #color
							              100,    #opacity 
							                0,    #mode - normal 
							               25,    #size 
							              100,    #position, 
							             TRUE)    #merge
    
    #Rename the layer   
    textLayer = pdb.gimp_image_get_layer_by_name(img, "Text")
    pdb.gimp_item_set_name(textLayer, "Text")
    pdb.gimp_layer_resize_to_image_size(textLayer)
    
    #Drop Shadow on the text
    pdb.python_layerfx_drop_shadow(img, textLayer,
										  ("Black"),   #color
											     35,   #opacity
												  0,   #contou - linear
												  0,   #noise
												  3,   #mode - multiply
												  7,   #spread
												 30,   #size
											   -150,   #offset_angle
											     30,   #offset_distance
											   TRUE,   #knockout
											  FALSE)   #merge
    
    pdb.gimp_image_scale(img, imagesize, imagesize)
    
    #Set gimp to default
    pdb.gimp_context_set_defaults()
    pdb.gimp_context_set_default_colors()
    pdb.gimp_displays_flush()

register(
    "create_paper_heart_valentie_cardV2",
    "Creates a paper heart for Valentine",
    "Creates a paper heart with a flower for Valentine",
    "Pocholo",
    "Pocholo",
    "2021",
    "Create a Paper Heart for valentineV2",
    "RGB*, GRAY*",
	[
    (PF_IMAGE, "img", "Image", None), 
    (PF_LAYER, "layer", "Layer", None),
    (PF_FILENAME, "filename1", ".SVG Heart:", None),
    (PF_FILENAME, "filename2", ".SVG Heart lines:", None),
    (PF_STRING, "customtext", "Text string", 'You are Loved'),
	(PF_FONT, "fontname", "Font name", "Allura"),
	(PF_SPINNER, "size", "Text size", 350, (300, 350, 1)),
    (PF_SPINNER, "imagesize", "Image size", 1600, (1000, 2000, 1)),
        
	],
	[],
	create_paper_heart_valentie_cardV2, menu="<Image>/Pocholo-scripts/Create a Paper Heart for valentineV2",
    domain=("gimp20", gimp.locale_directory))
main()			